{% load i18n %}

<script>
    var TRAFFIC_CATEGORIES = [{% for label in widget.labels %}'{{ label }}'{% if not forloop.last %},{% endif %}{% endfor %}]
    var TRAFFIC_DATAS = [{% for value in widget.values %}{{ value }}{% if not forloop.last %},{% endif %}{% endfor %}]
</script>

<div class="panel traffic-overview">
    <div class="panel-heading">{{ widget.title }}</div>
    <div class="panel-body">
    </div>
</div>
